@@ -4,14 +4,13 @@
 # Distributed under the Boost Software License, Version 1.0. (See accompanying
 # file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
-cxx_std="20"
 clang_version="11.0.1"
 boost_version="1.78.0"
 hwloc_version="2.2.0"
 spack_compiler="clang@${clang_version}"
 spack_arch="cray-cnl7-broadwell"
 
-spack_spec="pika@main arch=${spack_arch} %${spack_compiler} malloc=jemalloc cxxstd=${cxx_std} ^boost@${boost_version} ^hwloc@${hwloc_version}"
+spack_spec="pika@main arch=${spack_arch} %${spack_compiler} malloc=mimalloc ^boost@${boost_version} ^hwloc@${hwloc_version}"
 
-configure_extra_options+=" -DPIKA_WITH_CXX_STANDARD=${cxx_std}"
-configure_extra_options+=" -DPIKA_WITH_MALLOC=jemalloc"
+export MIMALLOC_EAGER_COMMIT_DELAY=0
+export MIMALLOC_LARGE_OS_PAGES=1
