@@ -12,7 +12,4 @@
 # endif
 #endif
 
-int main()
-{
-    return 0;
-}
+int main() { return 0; }
