@@ -6,9 +6,9 @@
 //  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
 #include <pika/config.hpp>
-#if defined(__linux) || defined(linux) || defined(__linux__) ||                \
-    defined(__FreeBSD__) || defined(__APPLE__)
-#include <pika/coroutines/detail/posix_utility.hpp>
+#if defined(__linux) || defined(linux) || defined(__linux__) || defined(__FreeBSD__) ||            \
+    defined(__APPLE__)
+# include <pika/coroutines/detail/posix_utility.hpp>
 
 namespace pika::threads::coroutines::detail ::posix {
     ///////////////////////////////////////////////////////////////////////
