@@ -57,7 +57,11 @@
 // when debugging is disabled
 #define PIKA_DETAIL_DP_LAZY(printer, Expr) printer.eval([&] { return Expr; })
 #define PIKA_DETAIL_DP(printer, Expr)                                                              \
-    if constexpr (printer.is_enabled()) { printer.Expr; };
+    if constexpr (printer.is_enabled())                                                            \
+    {                                                                                              \
+        using namespace pika::debug::detail;                                                       \
+        printer.Expr;                                                                              \
+    };
 
 #define PIKA_DETAIL_NS_DEBUG pika::debug::detail
 
@@ -279,6 +283,7 @@ namespace PIKA_DETAIL_NS_DEBUG {
     // ------------------------------------------------------------------
     struct hostname_print_helper
     {
+        PIKA_EXPORT char const* get_hostname_and_rank() const;
         PIKA_EXPORT char const* get_hostname() const;
         PIKA_EXPORT int guess_rank() const;
 
