@@ -34,7 +34,7 @@ namespace pika::drop_value_detail {
     template <typename Receiver>
     struct drop_value_receiver_impl<Receiver>::drop_value_receiver_type
     {
-        using is_receiver = void;
+        PIKA_STDEXEC_RECEIVER_CONCEPT
 
         PIKA_NO_UNIQUE_ADDRESS std::decay_t<Receiver> receiver;
 
@@ -78,7 +78,7 @@ namespace pika::drop_value_detail {
     template <typename Sender>
     struct drop_value_sender_impl<Sender>::drop_value_sender_type
     {
-        using is_sender = void;
+        PIKA_STDEXEC_SENDER_CONCEPT
 
         PIKA_NO_UNIQUE_ADDRESS std::decay_t<Sender> sender;
 
@@ -120,7 +120,7 @@ namespace pika::drop_value_detail {
                 r.sender, drop_value_receiver<Receiver>{PIKA_FORWARD(Receiver, receiver)});
         }
 
-        friend constexpr decltype(auto) tag_invoke(
+        friend decltype(auto) tag_invoke(
             pika::execution::experimental::get_env_t, drop_value_sender_type const& s) noexcept
         {
             return pika::execution::experimental::get_env(s.sender);
