@@ -20,9 +20,13 @@
 #include <pika/threading_base/thread_helpers.hpp>
 #include <pika/threading_base/thread_pool_base.hpp>
 
+#include <fmt/ostream.h>
+#include <fmt/printf.h>
+
 #include <atomic>
 #include <cstddef>
 #include <cstdlib>
+#include <iostream>
 #include <memory>
 #include <string>
 #include <utility>
@@ -117,6 +121,8 @@ int pika_main()
 
 void test_scheduler(int argc, char* argv[], pika::resource::scheduling_policy scheduler)
 {
+    fmt::print(std::cerr, "Testing scheduler: {}\n", scheduler);
+
     using ::pika::threads::scheduler_mode;
 
     pika::init_params init_args;
