@@ -4,13 +4,17 @@
 //  Distributed under the Boost Software License, Version 1.0. (See accompanying
 //  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
+#include <pika/execution.hpp>
 #include <pika/init.hpp>
-#include <pika/modules/async.hpp>
 #include <pika/modules/threading_base.hpp>
 #include <pika/testing.hpp>
 
 #include <atomic>
 #include <cstddef>
+#include <cstdlib>
+
+namespace ex = pika::execution::experimental;
+namespace tt = pika::this_thread::experimental;
 
 std::atomic<bool> data_deallocated(false);
 
@@ -39,9 +43,11 @@ void test()
 
 int pika_main()
 {
-    pika::async(&test).get();
+    tt::sync_wait(ex::schedule(ex::thread_pool_scheduler{}) | ex::then(test));
     PIKA_TEST(data_deallocated);
-    return pika::finalize();
+
+    pika::finalize();
+    return EXIT_SUCCESS;
 }
 
 int main(int argc, char* argv[])
